@@ -11,17 +11,16 @@ module RewriterSpec where
 import Control.Monad (forM_, unless)
 import Data.Aeson
 import Data.Char (isSpace)
-import Data.Foldable (foldlM)
 import Data.Yaml qualified as Yaml
 import GHC.Generics
 import Misc (allPathsIn, ensuredFile)
 import Parser (parseProgramThrows)
 import Pretty (prettyProgram)
-import Rewriter (rewrite)
 import System.FilePath (makeRelative, replaceExtension, (</>))
 import Test.Hspec (Spec, describe, expectationFailure, it, pending, runIO)
 import Yaml (normalizationRules)
 import Yaml qualified as Y
+import Rewriter (rewrite')
 
 data Rules = Rules
   { basic :: Maybe [String],
@@ -92,7 +91,7 @@ spec =
                   if normalize'
                     then pure normalizationRules
                     else pure []
-              rewritten <- foldlM (\prog _ -> rewrite prog rules') program [1 .. repeat']
+              rewritten <- rewrite' program program rules' repeat'
               result' <- parseProgramThrows (output pack)
               unless (rewritten == result') $
                 expectationFailure
